#internal gem test suite for BankValInternational

$:.unshift File.join(File.dirname(__FILE__),'..','lib')

require 'test/unit'
require 'BankValInternational'
require 'rexml/document'
require 'rubygems'
require 'json'

  class BvIntGetAbaTest < Test::Unit::TestCase
    @obj
    def setup
      @obj = BankValInternational::GetABA.new
    end
    
    def test_return_validation_aba
      #test1_1 'J-Son' is rejected as invalid result format
      assert_match /INVALID - Result Format/,@obj.bankval_int_getaba('J-Son','12345678','abcd123','12345')
      #tests 1_2 to 1_4 test that 'json','xml','csv' are not rejected as invalis result formats
      assert_no_match /INVALID - Result Format/,@obj.bankval_int_getaba('json','12345678','abcd123','12345')
      assert_no_match /INVALID - Result Format/,@obj.bankval_int_getaba('xml','12345678','abcd123','12345')
      assert_no_match /INVALID - Result Format/,@obj.bankval_int_getaba('csv','12345678','abcd123','12345')
      #test1_5 tests that csv is returned as the first part of the string will be 'INVALID'
      assert_match /^INVALID/,@obj.bankval_int_getaba('csv','12345678','abcd123','12345')
      #test1_6 tests 'json' fails the csv test5
      assert_no_match /^INVALID/,@obj.bankval_int_getaba('json','12345678','abcd123','12345')
      #test1_7 tests xml is returned as no parseError will be raised
      assert_nothing_raised{
        REXML::Document.new(@obj.bankval_int_getaba('xml','12345678','abcd123','12345')).root.name
      }
      #test1_8 tests 'json' fails this xml parse i.e. json doesn't return xml
      assert_raise (NoMethodError){
        REXML::Document.new(@obj.bankval_int_getaba('json','12345678','abcd123','12345')).root.name
      }
      #test1_9 tests 'csv' fails xml parse i.e. csv doesn't return xml
      assert_raise (NoMethodError){
        REXML::Document.new(@obj.bankval_int_getaba('csv','12345678','abcd123','12345')).root.name
      }
      #test1_10 tests 'xml' doesn't return json as parse error is raised
      assert_raise (JSON::ParserError) {
        JSON[@obj.bankval_int_getaba('xml','12345678','abcd123','12345')]
      }
      #test1_11 tests 'csv' doesn't return json
      assert_raise (JSON::ParserError) {
        JSON[@obj.bankval_int_getaba('csv','12345678','abcd123','12345')]
      }
      #test1_12 tests ''json' returns valid (parsable) json
      assert_nothing_raised{
        JSON[@obj.bankval_int_getaba('json','12345678','abcd123','12345')]
      }
    end

    def test_aba_number_validation
      #test2_1 check under sized aba is rejected (invalid userid/pin would error first on server)
      assert_match /^\{"result":"INVALID","routingnumber"/, @obj.bankval_int_getaba('json','12345678','abcd123','12345')
      #test2_2 check oversized aba is rejected
      assert_match /^\{"result":"INVALID","routingnumber"/, @obj.bankval_int_getaba('json','1234567890','abcd123','12345')
      #test2_3 check leading alpha is rejected
      assert_match /^\{"result":"INVALID","routingnumber"/, @obj.bankval_int_getaba('json','l12345678','abcd123','12345')
      #test2_4 check trailing alpha is rejected
      assert_match /^\{"result":"INVALID","routingnumber"/, @obj.bankval_int_getaba('json','12345678g','abcd123','12345')
      #test2_5 check embedded alpha is rejected
      assert_match /^\{"result":"INVALID","routingnumber"/, @obj.bankval_int_getaba('json','1234S5678','abcd123','12345')
      #test2_6 check correct size passes (error will be ID/PIN from server)
      assert_match /^\{"result":"ERROR - Invalid User ID\/PIN","routingnumber"/, @obj.bankval_int_getaba('json','123456789','abcd123','12345')
    end

    def test_userid_validation #test with wireshark as well as returns are identical from server and client validation
      #test3_1 too short user id 2nd element
      assert_match /^\{"result":"ERROR - Invalid User ID\/PIN","routingnumber"/, @obj.bankval_int_getaba('json','123456789','abcd12','12345')
      #test3_2 too long user id 2nd element
      assert_match /^\{"result":"ERROR - Invalid User ID\/PIN","routingnumber"/, @obj.bankval_int_getaba('json','123456789','abcd1234','12345')
      #test3_3 too short first element
      assert_match /^\{"result":"ERROR - Invalid User ID\/PIN","routingnumber"/, @obj.bankval_int_getaba('json','123456789','ab123','12345')
    end

    def test_pin #test with wireshark as well (look for client hellos these will match each call to either server)
      #test4_1 too short
      assert_match /^\{"result":"ERROR - Invalid User ID\/PIN","routingnumber"/, @obj.bankval_int_getaba('json','123456789','abcd012','1234')
      #test4_2 too long
      assert_match /^\{"result":"ERROR - Invalid User ID\/PIN","routingnumber"/, @obj.bankval_int_getaba('json','123456789','abcd123','123456')
      #test4_3 bad chars
      assert_match /^\{"result":"ERROR - Invalid User ID\/PIN","routingnumber"/, @obj.bankval_int_getaba('json','123456789','abcd123','12{45')    end
  end

  class BvIntGetSWIFTTest < Test::Unit::TestCase
    @obj
    def setup
      @obj = BankValInternational::GetSWIFT.new
    end

    def test_return_validation_aba
      #test1_1 'J-Son' is rejected as invalid result format
      assert_match /INVALID - Result Format/,@obj.bankval_int_getswift('J-Son','ABICAB99K','abcd123','12345')
      #tests 1_2 to 1_4 test that 'json','xml','csv' are not rejected as invalis result formats
      assert_no_match /INVALID - Result Format/,@obj.bankval_int_getswift('json','ABICAB99K','abcd123','12345')
      assert_no_match /INVALID - Result Format/,@obj.bankval_int_getswift('xml','ABICAB99K','abcd123','12345')
      assert_no_match /INVALID - Result Format/,@obj.bankval_int_getswift('csv','ABICAB99K','abcd123','12345')
      #test1_5 tests that csv is returned as the first part of the string will be 'INVALID'
      assert_match /^INVALID/,@obj.bankval_int_getswift('csv','ABICAB9','abcd123','12345')
      #test1_6 tests 'json' fails the csv test5
      assert_no_match /^INVALID/,@obj.bankval_int_getswift('json','ABICAB99K','abcd123','12345')
      #test1_7 tests xml is returned as no parseError will be raised
      assert_nothing_raised{
        REXML::Document.new(@obj.bankval_int_getswift('xml','ABICAB99K','abcd123','12345')).root.name
      }
      #test1_8 tests 'json' fails this xml parse i.e. json doesn't return xml
      assert_raise (NoMethodError){
        REXML::Document.new(@obj.bankval_int_getswift('json','ABICAB99K','abcd123','12345')).root.name
      }
      #test1_9 tests 'csv' fails xml parse i.e. csv doesn't return xml
      assert_raise (NoMethodError){
        REXML::Document.new(@obj.bankval_int_getswift('csv','ABICAB99K','abcd123','12345')).root.name
      }
      #test1_10 tests 'xml' doesn't return json as parse error is raised
      assert_raise (JSON::ParserError) {
        JSON[@obj.bankval_int_getswift('xml','ABICAB99K','abcd123','12345')]
      }
      #test1_11 tests 'csv' doesn't return json
      assert_raise (JSON::ParserError) {
        JSON[@obj.bankval_int_getswift('csv','ABICAB99K','abcd123','12345')]
      }
      #test1_12 tests ''json' returns valid (parsable) json
      assert_nothing_raised{
        JSON[@obj.bankval_int_getswift('json','ABICAB99K','abcd123','12345')]
      }
    end

    def test_iban_number_validation
      #test2_1 check under sized IBAN is rejected (invalid userid/pin would error first on server)
      assert_match /^\{"result":"INVALID","bic"/, @obj.bankval_int_getswift('json','ABICAB9','abcd123','12345')
      #test2_2 check oversized bic is rejected
      assert_match /^\{"result":"INVALID","bic"/, @obj.bankval_int_getswift('json','ABICAB9990','abcd123','12345')
      #test2_3 check leading special char is rejected
      assert_match /^\{"result":"INVALID","bic"/, @obj.bankval_int_getswift('json','?BICAB99','abcd123','12345')
      #test2_4 check trailing special char is rejected
      assert_match /^\{"result":"INVALID","bic"/, @obj.bankval_int_getswift('json','ABICAB9)','abcd123','12345')
      #test2_5 check embedded special char is rejected
      assert_match /^\{"result":"INVALID","bic"/, @obj.bankval_int_getswift('json','ABIC@B99','abcd123','12345')
      #test2_6 check correct size passes (error will be ID/PIN from server)
      assert_match /^\{"result":"ERROR - Invalid User ID\/PIN","bic"/, @obj.bankval_int_getswift('json','ABIBAB99','abcd123','12345')
    end

    def test_userid_validation #test with wireshark as well as returns are identical from server and client validation
      #test3_1 too short user id 2nd element
      assert_match /^\{"result":"ERROR - Invalid User ID\/PIN","bic"/, @obj.bankval_int_getswift('json','ABICAB99','abcd12','12345')
      #test3_2 too long user id 2nd element
      assert_match /^\{"result":"ERROR - Invalid User ID\/PIN","bic"/, @obj.bankval_int_getswift('json','ABICAB99','abcd1234','12345')
      #test3_3 too short first element
      assert_match /^\{"result":"ERROR - Invalid User ID\/PIN","bic"/, @obj.bankval_int_getswift('json','ABICAB99','ab123','12345')
    end

    def test_pin #test with wireshark as well (look for client hellos these will match each call to either server)
      #test4_1 too short
      assert_match /^\{"result":"ERROR - Invalid User ID\/PIN","bic"/, @obj.bankval_int_getswift('json','ABICAB99','abcd012','1234')
      #test4_2 too long
      assert_match /^\{"result":"ERROR - Invalid User ID\/PIN","bic"/, @obj.bankval_int_getswift('json','ABICAB99','abcd123','123456')
      #test4_3 bad chars
      assert_match /^\{"result":"ERROR - Invalid User ID\/PIN","bic"/, @obj.bankval_int_getswift('json','ABICAB99','abcd123','12{45')
    end
  end

  class BvIntGetIBANTest < Test::Unit::TestCase
    @obj
    def setup
      @obj = BankValInternational::GetIBAN.new
    end

    def test_return_validation_iban
      #test1_1 'J-Son' is rejected as invalid result format
      assert_match /INVALID - Result Format/,@obj.bankval_int_ibanval('J-Son','ABCDEFGHIJKLMNOPQRSTUVWXYZ123456789','abcd123','12345')
      #tests 1_2 to 1_4 test that 'json','xml','csv' are not rejected as invalis result formats
      assert_no_match /INVALID - Result Format/,@obj.bankval_int_ibanval('json','ABCDEFGHIJKLMNOPQRSTUVWXYZ123456789','abcd123','12345')
      assert_no_match /INVALID - Result Format/,@obj.bankval_int_ibanval('xml','ABCDEFGHIJKLMNOPQRSTUVWXYZ123456789','abcd123','12345')
      assert_no_match /INVALID - Result Format/,@obj.bankval_int_ibanval('csv','ABCDEFGHIJKLMNOPQRSTUVWXYZ123456789','abcd123','12345')
      #test1_5 tests that csv is returned as the first part of the string will be 'INVALID'
      assert_match /^INVALID/,@obj.bankval_int_ibanval('csv','ABCDEFGHIJKLMNOPQRSTUVWXYZ123456789','abcd123','12345')
      #test1_6 tests 'json' fails the csv test5
      assert_no_match /^INVALID/,@obj.bankval_int_ibanval('json','ABCDEFGHIJKLMNOPQRSTUVWXYZ123456789','abcd123','12345')
      #test1_7 tests xml is returned as no parseError will be raised
      assert_nothing_raised{
        REXML::Document.new(@obj.bankval_int_ibanval('xml','ABCDEFGHIJKLMNOPQRSTUVWXYZ123456789','abcd123','12345')).root.name
      }
      #test1_8 tests 'json' fails this xml parse i.e. json doesn't return xml
      assert_raise (NoMethodError){
        REXML::Document.new(@obj.bankval_int_ibanval('json','ABCDEFGHIJKLMNOPQRSTUVWXYZ123456789','abcd123','12345')).root.name
      }
      #test1_9 tests 'csv' fails xml parse i.e. csv doesn't return xml
      assert_raise (NoMethodError){
        REXML::Document.new(@obj.bankval_int_ibanval('csv','ABCDEFGHIJKLMNOPQRSTUVWXYZ123456789','abcd123','12345')).root.name
      }
      #test1_10 tests 'xml' doesn't return json as parse error is raised
      assert_raise (JSON::ParserError) {
        JSON[@obj.bankval_int_ibanval('xml','ABCDEFGHIJKLMNOPQRSTUVWXYZ123456789','abcd123','12345')]
      }
      #test1_11 tests 'csv' doesn't return json
      assert_raise (JSON::ParserError) {
        JSON[@obj.bankval_int_ibanval('csv','ABCDEFGHIJKLMNOPQRSTUVWXYZ123456789','abcd123','12345')]
      }
      #test1_12 tests ''json' returns valid (parsable) json
      assert_nothing_raised{
        JSON[@obj.bankval_int_ibanval('json','ABCDEFGHIJKLMNOPQRSTUVWXYZ123456789','abcd123','12345')]
      }
    end

    def test_iban_number_validation
      #test2_1 check oversized iban is rejected
      assert_match /^\{"result":"INVALID - FORMAT"/, @obj.bankval_int_ibanval('json','ABCDEFGHIJKLMNOPQRSTUVWXYZ123456789','abcd123','12345')
      #test2_2 check leading special char is rejected
      assert_match /^\{"result":"INVALID - FORMAT"/, @obj.bankval_int_ibanval('json','*ABCDEFGHIJKLMNOPQRSTUVWXYZ1234567','abcd123','12345')
      #test2_3 check trailing special char is rejected
      assert_match /^\{"result":"INVALID - FORMAT"/, @obj.bankval_int_ibanval('json','ABCDEFGHIJKLMNOPQRSTUVWXYZ123:','abcd123','12345')
      #test2_4 check embedded special char is rejected
      assert_match /^\{"result":"INVALID - FORMAT"/, @obj.bankval_int_ibanval('json','SJKDFHJKSGHKJDFGH&&KLFJGDKLFJF','abcd123','12345')
      #test2_5 check correct size passes (error will be ID/PIN from server)
      assert_match /^\{"result":"ERROR - Invalid User ID\/PIN"/, @obj.bankval_int_ibanval('json','ABCDEFGHIJKLMNOPQRSTUVWXYZ12345678','abcd123','12345')
    end

    def test_userid_validation #test with wireshark as well as returns are identical from server and client validation
      #test3_1 too short user id 2nd element
      assert_match /^\{"result":"ERROR - Invalid User ID\/PIN"/, @obj.bankval_int_ibanval('json','ABCDEFGHIJKLMNOPQRSTUVWXYZ12345678','abcd12','12345')
      #test3_2 too long user id 2nd element
      assert_match /^\{"result":"ERROR - Invalid User ID\/PIN"/, @obj.bankval_int_ibanval('json','ABCDEFGHIJKLMNOPQRSTUVWXYZ12345678','abcd1234','12345')
      #test3_3 too short first element
      assert_match /^\{"result":"ERROR - Invalid User ID\/PIN"/, @obj.bankval_int_ibanval('json','ABCDEFGHIJKLMNOPQRSTUVWXYZ12345678','ab123','12345')
    end

    def test_pin #test with wireshark as well (look for client hellos these will match each call to either server)
      #test4_1 too short
      assert_match /^\{"result":"ERROR - Invalid User ID\/PIN"/, @obj.bankval_int_ibanval('json','ABCDEFGHIJKLMNOPQRSTUVWXYZ12345678','abcd012','1234')
      #test4_2 too long
      assert_match /^\{"result":"ERROR - Invalid User ID\/PIN"/, @obj.bankval_int_ibanval('json','ABCDEFGHIJKLMNOPQRSTUVWXYZ12345678','abcd123','123456')
      #test4_3 bad chars
      assert_match /^\{"result":"ERROR - Invalid User ID\/PIN"/, @obj.bankval_int_ibanval('json','ABCDEFGHIJKLMNOPQRSTUVWXYZ12345678','abcd123','12{45')
    end
  end

